# Qsavvy


[![pypi](https://img.shields.io/pypi/v/qsavvy.svg)](https://pypi.org/project/qsavvy/)
[![python](https://img.shields.io/pypi/pyversions/qsavvy.svg)](https://pypi.org/project/qsavvy/)
[![Build Status](https://github.com/anomius/qsavvy/actions/workflows/dev.yml/badge.svg)](https://github.com/anomius/qsavvy/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/anomius/qsavvy/branch/main/graphs/badge.svg)](https://codecov.io/github/anomius/qsavvy)



savvy's Quantum Stuff


* Documentation: <https://anomius.github.io/qsavvy>
* GitHub: <https://github.com/anomius/qsavvy>
* PyPI: <https://pypi.org/project/qsavvy/>
* Free software: BSD-3-Clause


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
